pub struct ServiceInstanceOptions {
pub instance_id: String,
pub node_id: Option<String>,
pub service_id: String,
pub host: String,
pub status: ServiceStatus,
pub tags: Option<Vec<String>>,
pub port: u32,
pub secure: bool,
pub state: Option<ServiceInstanceState>,
pub metadata: Option<HashMap<String, String>>,
}Expand description
ServiceInstance
Fields
instance_id: Stringinstance_id the id of the instance.
node_id: Option<String>Node the id of the instance.
service_id: Stringservice_id the id of the service.
host: Stringhost where the service instance can be found.
status: ServiceStatusservice instance status.
service tags.
port: u32port the port on which the service is running.
secure: boolsecure indicates whether or not the connection needs to be secure.
state: Option<ServiceInstanceState>node instance state.
metadata: Option<HashMap<String, String>>metadata optional a map containing metadata.